@@ -200,7 +200,7 @@ class Metamist:
             entries_by_sid[entry['sample_id']].append(entry)
         return entries_by_sid
 
-    def get_participant_entries_by_sid(self, dataset_name: str) -> dict[str, str]:
+    def get_participant_entries_by_sid(self, dataset_name: str) -> dict[str, dict]:
         """
         Retrieve participant entries for a dataset, in the context of access level.
         """
@@ -211,12 +211,24 @@ class Metamist:
         pid_sid_multi = self.papi.get_external_participant_id_to_internal_sample_id(
             metamist_proj
         )
-        participant_by_sid = {}
+        sid_by_pid = {}
         for group in pid_sid_multi:
-            pid = group[0]
+            pid = group[0].strip()
             for sid in group[1:]:
-                participant_by_sid[sid] = pid.strip()
-        return participant_by_sid
+                sid_by_pid[pid] = sid
+
+        entries = self.papi.get_participants(metamist_proj)
+        participant_entry_by_sid = {}
+        for entry in entries:
+            pid = entry['external_id']
+            if not (sid := sid_by_pid.get(pid)):
+                raise MetamistError(
+                    f'papi.get_participants returned participant that was not returned '
+                    f'by papi.get_external_participant_id_to_internal_sample_id: '
+                    f'{entry}'
+                )
+            participant_entry_by_sid[sid] = entry
+        return participant_entry_by_sid
 
     def update_analysis(self, analysis: Analysis, status: AnalysisStatus):
         """
@@ -453,8 +465,8 @@ class Metamist:
         if get_config()['workflow']['access_level'] == 'test':
             metamist_proj += '-test'
 
-        families = self.fapi.get_families(metamist_proj)
-        family_ids = [family['id'] for family in families]
+        entries = self.fapi.get_families(metamist_proj)
+        family_ids = [entry['id'] for entry in entries]
         ped_entries = self.fapi.get_pedigree(
             internal_family_ids=family_ids,
             export_type='json',
@@ -501,17 +513,13 @@ class Sequence:
             meta=data['meta'],
             sequencing_type=sequencing_type,
         )
-        if data['meta'].get('reads'):
-            if alignment_input := Sequence._parse_reads(
-                sample_id=sample_id,
-                meta=data['meta'],
-                check_existence=check_existence,
-            ):
-                mm_seq.alignment_input = alignment_input
-        else:
-            logging.warning(
-                f'{sample_id} sequence: no meta/reads found with FASTQ information'
-            )
+        alignment_input = Sequence._parse_reads(
+            sample_id=sample_id,
+            meta=data['meta'],
+            check_existence=check_existence,
+        )
+        assert alignment_input, (sample_id, data)
+        mm_seq.alignment_input = alignment_input
         return mm_seq
 
     @staticmethod
